#!/bin/sh

# NAME:
#	dnssec-key-init.sh - DNSSec key initialization
#
# SYNOPSIS:
#	dnssec-key-init.sh [-g "group"] [-K "keydir"] "zone"
#
# DESCRIPTION:
#	When we checkout the 'named' repository for editing, we need
#	to establish random keys if DNSSEC is enabled.
#
#	Create "keydir"/"zone" and ensure only owner and "group"
#	can read "keydir".
#
#	Throw an error if any keys exist for "zone".
#	Otherwise we create KSK and ZSK keys.
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: dnssec-key-init.sh,v 1.3 2022/10/08 19:04:09 sjg Exp $
#
#	@(#) Copyright (c) 2022 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

opt_str=g:K:n
opt_g=bind
opt_K=keys
. setopts.sh

zone=`echo $1 | sed 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/;s,\.$,,'`

error() {
    echo "ERROR: $@"
    exit 1
}

ECHO=
Do() {
    $ECHO "$@"
}

if [ -n "$opt_n" ]; then
    ECHO=echo
fi

Do mkdir -p $opt_K/$zone
Do chgrp $opt_g $opt_K
Do chmod 750 $opt_K

if [ -z "$opt_n" ]; then
    cd $opt_K/$zone || exit 1
else
    echo cd $opt_K/$zone
    cd $opt_K/$zone 2> /dev/null
fi

for k in K*.key
do
    test -s $k && error "exising key: $k"
done

# ZSK 1k to reduce overhead
Do dnssec-keygen -a RSASHA256 -b 1024 $zone
Do dnssec-keygen -a RSASHA256 -b 2048 -f KSK $zone
Do 'ls' -l
