:
# NAME:
#	ndconv - convert named.conf to named.boot
#
# SYNOPSIS:
#	ndconv named.conf > named.boot
#
# DESCRIPTION:
#	This script provides a function for extracting zone
#	definitions from BIND-9 config files and outputting them in a
#	form suitable for a BIND-4 config file.  It has several uses.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: ndconv.sh,v 1.7 2023/06/08 05:45:34 sjg Exp $
#
#	@(#) Copyright (c) 1997-2022 Simon J. Gerraty.
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

get_zones() {
	tr -d '";{}' < $1 | grep -v '^[ 	]*//' |
	awk '/include/ {
		print $0
	}
	/directory/ {
		print $0
	}
	/zone/ {
		z=$2; f=""; t=""; m="";
	}
	/primaries/ {
		m=$2
	}
	/type/ {
		t=$NF
	}
	/file/ {
		f=$NF
	}
	{
		if (f != "") {
			if (t == "secondary") {
				if (m != "") {
					print t,z,f,m
                                        f=""
				}
			} else {
			        print t,z,f
                                f=""
			}
		}
	}' | while read t z f m
	do
		case "$t" in
		include)	test -f $z || z=${dir:-.}/$z; get_zones $z;;
		directory)	dir=$z; echo $t $z;;
		primary)		echo primary $z $f;;
		secondary)		echo secondary $z $m $f;;
		hint)		echo . $f;;
		esac
	done
}

case $0 in
*ndconv*) get_zones $*;;
esac

